/**
 * 
 */
package net.vidageek.mirror;

import net.vidageek.mirror.get.GetterHandler;
import net.vidageek.mirror.invoke.InvocationHandler;
import net.vidageek.mirror.provider.ReflectionProvider;
import net.vidageek.mirror.reflect.AllReflectionHandler;
import net.vidageek.mirror.reflect.ReflectionHandler;
import net.vidageek.mirror.set.SetterHandler;

/**
 * Object to provide reflection for a Class object
 * 
 * @author jonasabreu
 */
public final class ClassController<T> {

	private final Class<T> clazz;

	private final ReflectionProvider provider;

	public ClassController(final ReflectionProvider provider, final Class<T> clazz) {
		this.provider = provider;
		if (clazz == null) {
			throw new IllegalArgumentException("clazz cannot be null");
		}
		this.clazz = clazz;
	}

	/**
	 * This part of the DSL controls invocation of methods and constructors.
	 * 
	 * @return An object to control invocation.
	 */
	public InvocationHandler<T> invoke() {
		return new InvocationHandler<T>(provider, clazz);
	}

	/**
	 * This part of the DSL controls setting of fields.
	 * 
	 * @return An object to control setting.
	 */
	public SetterHandler set() {
		return new SetterHandler(provider, clazz);
	}

	/**
	 * This part of the DSL controls getting field values.
	 * 
	 * @return An object to control getting of values.
	 */
	public GetterHandler get() {
		return new GetterHandler(provider, clazz);
	}

	/**
	 * This part of the DSL controls reflection of single reflection elements.
	 * 
	 * @return An object to control reflection of single reflection elements.
	 */
	public ReflectionHandler<T> reflect() {
		return new ReflectionHandler<T>(provider, clazz);
	}

	/**
	 * This part of the DSL controls reflection of lists of reflection elements.
	 * 
	 * @return An object to control reflection of lists of reflection elements.
	 */
	public AllReflectionHandler<T> reflectAll() {
		return new AllReflectionHandler<T>(provider, clazz);
	}

}
