package net.vidageek.mirror;

import java.lang.reflect.AccessibleObject;

import net.vidageek.mirror.provider.ReflectionProvider;

/**
 * This is the base class to provide reflection features. Mirror delegates to
 * it.
 * 
 * @see Mirror
 * 
 * @author jonasabreu
 */
public final class MirrorInfrastructure {

	private final ReflectionProvider provider;

	public MirrorInfrastructure(final ReflectionProvider provider) {
		this.provider = provider;
	}

	/**
	 * @see Mirror#reflectClass(String)
	 */
	public Class<?> reflectClass(final String className) {
		if (className == null || className.trim().length() == 0) {
			throw new IllegalArgumentException("className cannot be null or empty");
		}

		return provider.getClassReflectionProvider(className).reflectClass();
	}

	/**
	 * @see Mirror#on(Class)
	 */
	public <T> ClassController<T> on(final Class<T> clazz) {
		return new ClassController<T>(provider, clazz);
	}

	/**
	 * @see Mirror#on(Object)
	 */
	public ObjectController on(final Object object) {
		return new ObjectController(provider, object);
	}

	/**
	 * @see Mirror#on(String)
	 */
	public ClassController<?> on(final String className) {
		return on(reflectClass(className));
	}

	/**
	 * @see Mirror#on(AccessibleObject)
	 */
	public MemberController on(final AccessibleObject member) {
		return new MemberController(provider, member);
	}
}
