package net.vidageek.mirror.reflect;

import java.lang.annotation.Annotation;
import java.lang.reflect.AccessibleObject;
import java.util.List;

import net.vidageek.mirror.provider.AnnotatedElementReflectionProvider;
import net.vidageek.mirror.provider.ReflectionProvider;

/**
 * This class is responsible for reflecting all annotations on any
 * AccessibleObject
 * 
 * @author dnfeitosa
 */
public final class AllMemberHandler {

	private final AccessibleObject member;

	private final ReflectionProvider provider;

	public AllMemberHandler(final ReflectionProvider provider, final AccessibleObject member) {
		if (member == null) {
			throw new IllegalArgumentException("Argument member cannot be null");
		}
		this.provider = provider;
		this.member = member;
	}

	/**
	 * Use this method to reflect a list of annotations on the AccessibleObject
	 * 
	 * @return The list of annotation or a empty list if none was found.
	 * @see AnnotatedElementReflectionProvider#getAnnotations()
	 */
	public List<Annotation> annotations() {
		return provider.getAnnotatedElementReflectionProvider(member).getAnnotations();
	}

}
