package net.vidageek.mirror.reflect;

import java.lang.annotation.Annotation;
import java.lang.reflect.AccessibleObject;

import net.vidageek.mirror.provider.AnnotatedElementReflectionProvider;
import net.vidageek.mirror.provider.ReflectionProvider;

/**
 * This class is responsible for reflecting a single annotation from a
 * AccessibleObject
 * 
 * @author dnfeitosa
 */
public final class MemberHandler {

	private final AccessibleObject member;

	private final ReflectionProvider provider;

	public MemberHandler(final ReflectionProvider provider, final AccessibleObject member) {
		if (member == null) {
			throw new IllegalArgumentException("Argument member cannot be null");
		}
		this.provider = provider;
		this.member = member;
	}

	/**
	 * Use this method to reflect a single annotation from the AccessibleObject
	 * 
	 * @param annotation
	 *            Annotation type to be reflected.
	 * @return The annotation or null if it was not found.
	 * @see AnnotatedElementReflectionProvider#getAnnotation(Class)
	 */
	public Annotation annotation(final Class<? extends Annotation> annotation) {
		return provider.getAnnotatedElementReflectionProvider(member).getAnnotation(annotation);
	}
}
